<?php

class actionIbackuperRestore extends cmsAction {

	public function run() {
		
		$form = $this->getForm('restore');
		
        $is_submitted = $this->request->has('submit');

        if ($is_submitted){

			// загружаем файл
			$form_items = $form->parse($this->request, $is_submitted);
			
			// получаем содержимое файла
			$items = cmsModel::yamlToArray(file_get_contents(cmsConfig::get('upload_path') . $form_items['file_restore']['path']));
			
			if (!isset($items['ctype'])){
				echo LANG_IBACKUPER_EMPTY_FILE;
				cmsUser::addSessionMessage(LANG_IBACKUPER_EMPTY_FILE, 'error');
				header('Refresh: 0');
				$this->halt();
			}
			
			// удаляем файл
			cmsCore::getModel('files')->deleteFile($form_items['file_restore']['id']);
			unlink(cmsConfig::get('upload_path') . $form_items['file_restore']['path']);
			
			// подключаем модели
			$ibackuper_model = cmsCore::getModel('ibackuper');
			$content_model = cmsCore::getModel('content');
			
			// определяем, есть ли такой тип контента
			$use_prefix = $content_model->getContentTypeByName($items['ctype']['name']) ? true : false;
			
			// удаляем id старого типа контента и снимаем блокировку с нового типа контента
			unset($items['ctype']['id']);
			$items['ctype']['is_fixed'] = NULL;
			
			// если такой тип контента уже есть, используем префикс в названии.
			$items['ctype']['name'] = $use_prefix ? trim($form_items['name_prefix']) . $items['ctype']['name'] : $items['ctype']['name'];
			
			if ($use_prefix){
				// определяем, есть ли такой тип контента
				$isset_ctype = $content_model->getContentTypeByName($items['ctype']['name']) ? true : false;
				if ($isset_ctype){
					echo LANG_IBACKUPER_CTYPE_ISSET;
					cmsUser::addSessionMessage(LANG_IBACKUPER_CTYPE_ISSET, 'error');
					header('Refresh: 0');
					$this->halt();
				}
			}
			
			
			// добавляем новый тип контента
			$ctype_id = $content_model->addContentType($items['ctype']);
			
			// добавляем наборы
			if ($items['datasets']){
				
				foreach ($items['datasets'] as $name => $dataset){
					
					unset($dataset['id']);
					$dataset['ctype_id'] = $ctype_id;
					$ibackuper_model->insert('content_datasets', $dataset);
				}
			}
			
			// добавляем категории
			if ($items['cats']){
				
				ksort($items['cats']);
				
				$max_ns_right = 1;
				
				foreach ($items['cats'] as $key => $value){
					
					$max_ns_right = $value['ns_right'] > $max_ns_right ? $value['ns_right'] : $max_ns_right;
					
					if ($value['ns_differ'] == NULL){unset($value['ns_differ']);}
					
					$content_model->insert('con_' . $items['ctype']['name'] . '_cats', $value);
				}
				
				$content_model->update('con_' . $items['ctype']['name'] . '_cats', 1, array('ns_right' => $max_ns_right + 1));
			}
			
			// добавляем поля
			if ($items['fields']){
				
				$form_types = cmsForm::getAvailableFormFields(false);
				
				foreach ($items['fields'] as $name => $field){
					$items['fields'][$name]['ctype_id'] = $ctype_id;
					if (!array_key_exists($field['type'], $form_types) || !isset($field['type'])){unset($items['fields'][$name]);}
					unset($items['fields'][$name]['default'], $items['fields'][$name]['rules'], $items['fields'][$name]['handler'], $items['fields'][$name]['handler_title']);
				}
				$ibackuper_model->addCtypeFields($items['ctype']['name'], $items['fields']);
			}
			
			// добавляем свойства
			if ($items['props']){
				
				foreach ($items['props'] as $id => $prop){
					$prop['ctype_id'] = $ctype_id;
					if ($prop['options'] == '---'){$prop['options'] = null;}
					$ibackuper_model->insert('con_' . $items['ctype']['name'] . '_props', $prop);
				}
			}
			
			// добавляем связи свойств с категориями
			if ($items['props_bind']){
				
				foreach ($items['props_bind'] as $id => $prop){
					$ibackuper_model->insert('con_' . $items['ctype']['name'] . '_props_bind', array(
						'prop_id' => $prop['prop_id'],
						'cat_id' => $prop['cat_id'],
						'ordering' => $prop['ordering']
					));
				}
			}
			
			// добавляем модераторов
			if ($items['moderators']){
				$users_model = cmsCore::getModel('users');
				foreach ($items['moderators'] as $id => $moderator){
					$users_model->filterEqual('nickname', $moderator['user_nickname']);
					$users_model->filterEqual('id', $moderator['user_id']);
					if($users_model->getUsersIds()){
						$ibackuper_model->insert('moderators', array(
							'ctype_name' => $items['ctype']['name'],
							'user_id' => $moderator['user_id'],
							'date_assigned' => ''
						));
					}
				}
			}
			
			// добавляем доступы
			if ($items['perm_values']){
				cmsPermissions::savePermissions($items['ctype']['name'], $items['perm_values']);
			}
			
			cmsUser::addSessionMessage(sprintf(LANG_IBACKUPER_CTYPE_ADD_SUCCESS, $items['ctype']['name']), 'success');
			
			header('Refresh: 0');
			$this->halt();
		}
		
		// выводим форму
		return cmsTemplate::getInstance()->render('backend/restore', array(
			'form' => $form
		));
	}
}